        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 23 <strong>control</strong><br>0,1,4,5,6,8,10,11,13,18,25,26,31,32,33,35,37,38,40,41,45,46,48';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>15,17,19,20,21,22,27,29,30,34,36,39,42,44,47,49,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260513 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>24</strong> miembros: 11 <br>2,3,7,9,12,14,16,23,24,28,43';}
}
